@@ -123,11 +123,8 @@ struct dhcpcd_ctx {
 	struct dhcp_opt *dhcp6_opts;
 	size_t dhcp6_opts_len;
 	struct ipv6_ctx *ipv6;
-	char **ra_restore;
-	size_t ra_restore_len;
 #ifndef __linux__
 	int ra_global;
-	int ra_kernel_set;
 #endif
 #endif /* INET6 */
 
@@ -154,5 +151,6 @@ void dhcpcd_dropinterface(struct interface *, const char *);
 int dhcpcd_selectprofile(struct interface *, const char *);
 
 void dhcpcd_startinterface(void *);
+void dhcpcd_initstate(struct interface *);
 
 #endif
