@@ -72,10 +72,8 @@
 #endif
 
 /* This was fixed in NetBSD */
-#ifdef __NetBSD_Prereq__
-#  if __NetBSD_Prereq__(6, 99, 20)
-#    undef IPV6_POLLADDRFLAG
-#  endif
+#if defined(__NetBSD_Version__) && __NetBSD_Version__ >= 699002000
+#  undef IPV6_POLLADDRFLAG
 #endif
 
 struct ipv6_addr {
@@ -90,7 +88,10 @@ struct ipv6_addr {
 	short flags;
 	char saddr[INET6_ADDRSTRLEN];
 	uint8_t iaid[4];
+	uint16_t ia_type;
 	struct interface *delegating_iface;
+	uint8_t prefix_exclude_len;
+	struct in6_addr prefix_exclude;
 
 	void (*dadcallback)(void *);
 	int dadcounter;
@@ -109,7 +110,8 @@ TAILQ_HEAD(ipv6_addrhead, ipv6_addr);
 #define IPV6_AF_DADCOMPLETED	0x0040
 #define IPV6_AF_DELEGATED	0x0080
 #define IPV6_AF_DELEGATEDPFX	0x0100
-#define IPV6_AF_DELEGATEDZERO	0X0200
+#define IPV6_AF_DELEGATEDZERO	0x0200
+#define IPV6_AF_REQUEST		0x0400
 
 struct rt6 {
 	TAILQ_ENTRY(rt6) next;
