@@ -46,7 +46,7 @@
 #include <syslog.h>
 #include <unistd.h>
 
-#define ELOOP_QUEUE 2
+#define ELOOP_QUEUE 3
 #include "common.h"
 #include "dhcpcd.h"
 #include "dhcp6.h"
@@ -603,9 +603,14 @@ ipv6nd_dadcallback(void *arg)
 		 * Because ap->dadcounter is always increamented,
 		 * a different address is generated. */
 		/* XXX Cache DAD counter per prefix/id/ssid? */
-		if (ifp->options->options & DHCPCD_SLAACPRIVATE &&
-		    ap->dadcounter < IDGEN_RETRIES)
-		{
+		if (ifp->options->options & DHCPCD_SLAACPRIVATE) {
+			if (ap->dadcounter >= IDGEN_RETRIES) {
+				syslog(LOG_ERR,
+				    "%s: unable to obtain a"
+				    " stable private address",
+				    ifp->name);
+				goto try_script;
+			}
 			syslog(LOG_INFO, "%s: deleting address %s",
 				ifp->name, ap->saddr);
 			if (if_deladdress6(ap) == -1 &&
@@ -642,6 +647,7 @@ ipv6nd_dadcallback(void *arg)
 		}
 	}
 
+try_script:
 	if (!wascompleted) {
 		TAILQ_FOREACH(rap, ifp->ctx->ipv6->ra_routers, next) {
 			if (rap->iface != ifp)
